@@ -30,8 +30,11 @@
 #' from <- sample (graph$from_id, size = 100)
 #' dlim <- c (1, 2, 5, 10, 20) * 100
 #' d <- dodgr_isodists (graph, from = from, dlim)
-dodgr_isodists <- function (graph, from = NULL, dlim = NULL, heap = 'BHeap')
-{
+dodgr_isodists <- function (graph,
+                            from = NULL,
+                            dlim = NULL,
+                            heap = "BHeap") {
+
     if (is.null (dlim))
         stop ("dlim must be specified")
     if (!is.numeric (dlim))
@@ -65,8 +68,8 @@ dodgr_isodists <- function (graph, from = NULL, dlim = NULL, heap = 'BHeap')
     return (dmat_to_pts (d, dat$from_index$id, dat$v, dlim))
 }
 
-iso_pre <- function (graph, from = NULL, heap = "BHeap")
-{
+iso_pre <- function (graph, from = NULL, heap = "BHeap") {
+
     v <- dodgr_vertices (graph)
     graph <- tbl_to_df (graph)
 
@@ -75,8 +78,7 @@ iso_pre <- function (graph, from = NULL, heap = "BHeap")
     graph <- hps$graph
 
     gr_cols <- dodgr_graph_cols (graph)
-    if (is.na (gr_cols$from) | is.na (gr_cols$to))
-    {
+    if (is.na (gr_cols$from) | is.na (gr_cols$to)) {
         # nocov start - this is only tested on SC, so this never happens
         scols <- find_spatial_cols (graph)
         graph$from_id <- scols$xy_id$xy_fr_id
@@ -88,10 +90,8 @@ iso_pre <- function (graph, from = NULL, heap = "BHeap")
 
     tp <- attr (graph, "turn_penalty")
     tp <- ifelse (is.null (tp), 0, tp)
-    if (is (graph, "dodgr_streetnet_sc") & tp > 0)
-    {
-        if (!is.null (from))
-        {
+    if (is (graph, "dodgr_streetnet_sc") & tp > 0) {
+        if (!is.null (from)) {
             from <- nodes_arg_to_pts (from, graph)
             from <- remap_verts_with_turn_penalty (graph, from, from = TRUE)
         }
@@ -143,8 +143,11 @@ iso_pre <- function (graph, from = NULL, heap = "BHeap")
 #' tlim <- c (5, 10, 20, 30, 60) * 60 # times in seconds
 #' x <- dodgr_isochrones (graph, from = from, tlim)
 #' }
-dodgr_isochrones <- function (graph, from = NULL, tlim = NULL, heap = 'BHeap')
-{
+dodgr_isochrones <- function (graph,
+                              from = NULL,
+                              tlim = NULL,
+                              heap = "BHeap") {
+
     if (!methods::is (graph, "dodgr_streetnet_sc"))
         stop ("isochrones can only be calculated from SC-class networks ",
               "generated by osmdata_sc.")
@@ -192,9 +195,12 @@ dodgr_isochrones <- function (graph, from = NULL, tlim = NULL, heap = 'BHeap')
 #' tlim <- c (5, 10, 20, 30, 60) * 60 # times in seconds
 #' x <- dodgr_isoverts (graph, from = from, tlim)
 #' }
-dodgr_isoverts <- function (graph, from = NULL, dlim = NULL, tlim = NULL,
-                            heap = 'BHeap')
-{
+dodgr_isoverts <- function (graph,
+                            from = NULL,
+                            dlim = NULL,
+                            tlim = NULL,
+                            heap = "BHeap") {
+
     if (!methods::is (graph, "dodgr_streetnet_sc"))
         stop ("isoverts can only be calculated from SC-class networks ",
               "generated by osmdata_sc.")
@@ -202,8 +208,7 @@ dodgr_isoverts <- function (graph, from = NULL, dlim = NULL, tlim = NULL,
         stop ("Only one of dlim or tlim can be provided")
 
     has_tlim <- FALSE
-    if (!is.null (tlim))
-    {
+    if (!is.null (tlim)) {
         graph$d_weighted <- graph$time_weighted
         graph$d <- graph$time
         dlim <- tlim
@@ -247,12 +252,11 @@ dodgr_isoverts <- function (graph, from = NULL, dlim = NULL, tlim = NULL,
 
 # convert distance matrix with values equal to various isodistances into list of
 # lists of points ordered around the central points
-dmat_to_pts <- function (d, from, v, dlim)
-{
+dmat_to_pts <- function (d, from, v, dlim) {
+
     pt_names <- colnames (d)
     pts <- list ()
-    for (i in seq (nrow (d)))
-    {
+    for (i in seq (nrow (d))) {
         o <- v [match (from [i], v$id), ]
         pts [[i]] <- lapply (dlim, function (j) {
                                  res <- pt_names [which (d [i, ] == j)]
@@ -261,8 +265,7 @@ dmat_to_pts <- function (d, from, v, dlim)
                                                  d [i, ] < j)
                                  res <- c (res, pt_names [index])
                                  res <- v [match (res, v$id), ]
-                                 if (nrow (res) > 0)
-                                 {
+                                 if (nrow (res) > 0) {
                                      res$from <- o$id
                                      res <- order_points (res, o)
                                      res$dlim <- j
@@ -283,8 +286,8 @@ dmat_to_pts <- function (d, from, v, dlim)
 }
 
 # order points around circle
-order_points <- function (pts, origin)
-{
+order_points <- function (pts, origin) {
+
     dx <- pts$x - origin$x
     dy <- pts$y - origin$y
     theta <- rep (NA, nrow (pts))
