@@ -7,7 +7,9 @@
 #include <fstream>
 
 #include <Rcpp.h>
-// [[Rcpp::depends(RcppParallel)]]
+// [[Rcpp::plugins(cpp11)]]
+// [[Rcpp::depends(RcppParallel,RcppThread)]]
+#include <RcppThread.h>
 #include <RcppParallel.h>
 
 #include "pathfinders.h"
@@ -33,8 +35,10 @@ void make_vert_to_edge_maps (const std::vector <std::string> &from,
         std::unordered_map <std::string, unsigned int> &verts_to_edge_map,
         std::unordered_map <std::string, double> &verts_to_dist_map);
 
+size_t get_chunk_size (const size_t nfrom);
 } // end namespace run_sp
 
+
 Rcpp::NumericMatrix rcpp_get_sp_dists (const Rcpp::DataFrame graph,
         const Rcpp::DataFrame vert_map_in,
         Rcpp::IntegerVector fromi,
@@ -48,6 +52,13 @@ Rcpp::NumericMatrix rcpp_get_sp_dists_par (const Rcpp::DataFrame graph,
         const std::string& heap_type,
         const bool is_spatial);
 
+Rcpp::NumericMatrix rcpp_get_sp_dists_paired_par (const Rcpp::DataFrame graph,
+        const Rcpp::DataFrame vert_map_in,
+        Rcpp::IntegerVector fromi,
+        Rcpp::IntegerVector toi,
+        const std::string& heap_type,
+        const bool is_spatial);
+
 Rcpp::NumericMatrix rcpp_get_iso (const Rcpp::DataFrame graph,
         const Rcpp::DataFrame vert_map_in,
         Rcpp::IntegerVector fromi,
@@ -59,3 +70,14 @@ Rcpp::List rcpp_get_paths (const Rcpp::DataFrame graph,
         Rcpp::IntegerVector fromi,
         Rcpp::IntegerVector toi_in,
         const std::string& heap_type);
+
+//----------------------------
+//----- functions in centrality.cpp
+//----------------------------
+
+Rcpp::NumericVector rcpp_centrality (const Rcpp::DataFrame graph,
+        const Rcpp::DataFrame vert_map_in,
+        const std::string& heap_type,
+        const double dist_threshold,
+        const bool edge_centrality,
+        const int sample);
